'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_draw_buffers'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_draw_buffers',error_checker=_errors._error_checker)
GL_DRAW_BUFFER0_ARB=_C('GL_DRAW_BUFFER0_ARB',0x8825)
GL_DRAW_BUFFER10_ARB=_C('GL_DRAW_BUFFER10_ARB',0x882F)
GL_DRAW_BUFFER11_ARB=_C('GL_DRAW_BUFFER11_ARB',0x8830)
GL_DRAW_BUFFER12_ARB=_C('GL_DRAW_BUFFER12_ARB',0x8831)
GL_DRAW_BUFFER13_ARB=_C('GL_DRAW_BUFFER13_ARB',0x8832)
GL_DRAW_BUFFER14_ARB=_C('GL_DRAW_BUFFER14_ARB',0x8833)
GL_DRAW_BUFFER15_ARB=_C('GL_DRAW_BUFFER15_ARB',0x8834)
GL_DRAW_BUFFER1_ARB=_C('GL_DRAW_BUFFER1_ARB',0x8826)
GL_DRAW_BUFFER2_ARB=_C('GL_DRAW_BUFFER2_ARB',0x8827)
GL_DRAW_BUFFER3_ARB=_C('GL_DRAW_BUFFER3_ARB',0x8828)
GL_DRAW_BUFFER4_ARB=_C('GL_DRAW_BUFFER4_ARB',0x8829)
GL_DRAW_BUFFER5_ARB=_C('GL_DRAW_BUFFER5_ARB',0x882A)
GL_DRAW_BUFFER6_ARB=_C('GL_DRAW_BUFFER6_ARB',0x882B)
GL_DRAW_BUFFER7_ARB=_C('GL_DRAW_BUFFER7_ARB',0x882C)
GL_DRAW_BUFFER8_ARB=_C('GL_DRAW_BUFFER8_ARB',0x882D)
GL_DRAW_BUFFER9_ARB=_C('GL_DRAW_BUFFER9_ARB',0x882E)
GL_MAX_DRAW_BUFFERS_ARB=_C('GL_MAX_DRAW_BUFFERS_ARB',0x8824)
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDrawBuffersARB(n,bufs):pass
