'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_INTEL_performance_query'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_INTEL_performance_query',error_checker=_errors._error_checker)
GL_PERFQUERY_COUNTER_DATA_BOOL32_INTEL=_C('GL_PERFQUERY_COUNTER_DATA_BOOL32_INTEL',0x94FC)
GL_PERFQUERY_COUNTER_DATA_DOUBLE_INTEL=_C('GL_PERFQUERY_COUNTER_DATA_DOUBLE_INTEL',0x94FB)
GL_PERFQUERY_COUNTER_DATA_FLOAT_INTEL=_C('GL_PERFQUERY_COUNTER_DATA_FLOAT_INTEL',0x94FA)
GL_PERFQUERY_COUNTER_DATA_UINT32_INTEL=_C('GL_PERFQUERY_COUNTER_DATA_UINT32_INTEL',0x94F8)
GL_PERFQUERY_COUNTER_DATA_UINT64_INTEL=_C('GL_PERFQUERY_COUNTER_DATA_UINT64_INTEL',0x94F9)
GL_PERFQUERY_COUNTER_DESC_LENGTH_MAX_INTEL=_C('GL_PERFQUERY_COUNTER_DESC_LENGTH_MAX_INTEL',0x94FF)
GL_PERFQUERY_COUNTER_DURATION_NORM_INTEL=_C('GL_PERFQUERY_COUNTER_DURATION_NORM_INTEL',0x94F1)
GL_PERFQUERY_COUNTER_DURATION_RAW_INTEL=_C('GL_PERFQUERY_COUNTER_DURATION_RAW_INTEL',0x94F2)
GL_PERFQUERY_COUNTER_EVENT_INTEL=_C('GL_PERFQUERY_COUNTER_EVENT_INTEL',0x94F0)
GL_PERFQUERY_COUNTER_NAME_LENGTH_MAX_INTEL=_C('GL_PERFQUERY_COUNTER_NAME_LENGTH_MAX_INTEL',0x94FE)
GL_PERFQUERY_COUNTER_RAW_INTEL=_C('GL_PERFQUERY_COUNTER_RAW_INTEL',0x94F4)
GL_PERFQUERY_COUNTER_THROUGHPUT_INTEL=_C('GL_PERFQUERY_COUNTER_THROUGHPUT_INTEL',0x94F3)
GL_PERFQUERY_COUNTER_TIMESTAMP_INTEL=_C('GL_PERFQUERY_COUNTER_TIMESTAMP_INTEL',0x94F5)
GL_PERFQUERY_DONOT_FLUSH_INTEL=_C('GL_PERFQUERY_DONOT_FLUSH_INTEL',0x83F9)
GL_PERFQUERY_FLUSH_INTEL=_C('GL_PERFQUERY_FLUSH_INTEL',0x83FA)
GL_PERFQUERY_GLOBAL_CONTEXT_INTEL=_C('GL_PERFQUERY_GLOBAL_CONTEXT_INTEL',0x00000001)
GL_PERFQUERY_GPA_EXTENDED_COUNTERS_INTEL=_C('GL_PERFQUERY_GPA_EXTENDED_COUNTERS_INTEL',0x9500)
GL_PERFQUERY_QUERY_NAME_LENGTH_MAX_INTEL=_C('GL_PERFQUERY_QUERY_NAME_LENGTH_MAX_INTEL',0x94FD)
GL_PERFQUERY_SINGLE_CONTEXT_INTEL=_C('GL_PERFQUERY_SINGLE_CONTEXT_INTEL',0x00000000)
GL_PERFQUERY_WAIT_INTEL=_C('GL_PERFQUERY_WAIT_INTEL',0x83FB)
@_f
@_p.types(None,_cs.GLuint)
def glBeginPerfQueryINTEL(queryHandle):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLuintArray)
def glCreatePerfQueryINTEL(queryId,queryHandle):pass
@_f
@_p.types(None,_cs.GLuint)
def glDeletePerfQueryINTEL(queryHandle):pass
@_f
@_p.types(None,_cs.GLuint)
def glEndPerfQueryINTEL(queryHandle):pass
@_f
@_p.types(None,arrays.GLuintArray)
def glGetFirstPerfQueryIdINTEL(queryId):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLuintArray)
def glGetNextPerfQueryIdINTEL(queryId,nextQueryId):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint,arrays.GLcharArray,_cs.GLuint,arrays.GLcharArray,arrays.GLuintArray,arrays.GLuintArray,arrays.GLuintArray,arrays.GLuintArray,arrays.GLuint64Array)
def glGetPerfCounterInfoINTEL(queryId,counterId,counterNameLength,counterName,counterDescLength,counterDesc,counterOffset,counterDataSize,counterTypeEnum,counterDataTypeEnum,rawCounterMaxValue):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLsizei,ctypes.c_void_p,arrays.GLuintArray)
def glGetPerfQueryDataINTEL(queryHandle,flags,dataSize,data,bytesWritten):pass
@_f
@_p.types(None,arrays.GLcharArray,arrays.GLuintArray)
def glGetPerfQueryIdByNameINTEL(queryName,queryId):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,arrays.GLcharArray,arrays.GLuintArray,arrays.GLuintArray,arrays.GLuintArray,arrays.GLuintArray)
def glGetPerfQueryInfoINTEL(queryId,queryNameLength,queryName,dataSize,noCounters,noInstances,capsMask):pass
