'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_KHR_robustness'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_KHR_robustness',error_checker=_errors._error_checker)
GL_CONTEXT_LOST=_C('GL_CONTEXT_LOST',0x0507)
GL_CONTEXT_LOST_KHR=_C('GL_CONTEXT_LOST_KHR',0x0507)
GL_CONTEXT_ROBUST_ACCESS=_C('GL_CONTEXT_ROBUST_ACCESS',0x90F3)
GL_CONTEXT_ROBUST_ACCESS_KHR=_C('GL_CONTEXT_ROBUST_ACCESS_KHR',0x90F3)
GL_GUILTY_CONTEXT_RESET=_C('GL_GUILTY_CONTEXT_RESET',0x8253)
GL_GUILTY_CONTEXT_RESET_KHR=_C('GL_GUILTY_CONTEXT_RESET_KHR',0x8253)
GL_INNOCENT_CONTEXT_RESET=_C('GL_INNOCENT_CONTEXT_RESET',0x8254)
GL_INNOCENT_CONTEXT_RESET_KHR=_C('GL_INNOCENT_CONTEXT_RESET_KHR',0x8254)
GL_LOSE_CONTEXT_ON_RESET=_C('GL_LOSE_CONTEXT_ON_RESET',0x8252)
GL_LOSE_CONTEXT_ON_RESET_KHR=_C('GL_LOSE_CONTEXT_ON_RESET_KHR',0x8252)
GL_NO_ERROR=_C('GL_NO_ERROR',0)
GL_NO_ERROR=_C('GL_NO_ERROR',0)
GL_NO_RESET_NOTIFICATION=_C('GL_NO_RESET_NOTIFICATION',0x8261)
GL_NO_RESET_NOTIFICATION_KHR=_C('GL_NO_RESET_NOTIFICATION_KHR',0x8261)
GL_RESET_NOTIFICATION_STRATEGY=_C('GL_RESET_NOTIFICATION_STRATEGY',0x8256)
GL_RESET_NOTIFICATION_STRATEGY_KHR=_C('GL_RESET_NOTIFICATION_STRATEGY_KHR',0x8256)
GL_UNKNOWN_CONTEXT_RESET=_C('GL_UNKNOWN_CONTEXT_RESET',0x8255)
GL_UNKNOWN_CONTEXT_RESET_KHR=_C('GL_UNKNOWN_CONTEXT_RESET_KHR',0x8255)
@_f
@_p.types(_cs.GLenum,)
def glGetGraphicsResetStatus():pass
@_f
@_p.types(_cs.GLenum,)
def glGetGraphicsResetStatusKHR():pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLfloatArray)
def glGetnUniformfv(program,location,bufSize,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLfloatArray)
def glGetnUniformfvKHR(program,location,bufSize,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLintArray)
def glGetnUniformiv(program,location,bufSize,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLintArray)
def glGetnUniformivKHR(program,location,bufSize,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glGetnUniformuiv(program,location,bufSize,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glGetnUniformuivKHR(program,location,bufSize,params):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glReadnPixels(x,y,width,height,format,type,bufSize,data):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glReadnPixelsKHR(x,y,width,height,format,type,bufSize,data):pass
