'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_APPLE_texture_packed_float'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_APPLE_texture_packed_float',error_checker=_errors._error_checker)
GL_R11F_G11F_B10F_APPLE=_C('GL_R11F_G11F_B10F_APPLE',0x8C3A)
GL_RGB9_E5_APPLE=_C('GL_RGB9_E5_APPLE',0x8C3D)
GL_UNSIGNED_INT_10F_11F_11F_REV_APPLE=_C('GL_UNSIGNED_INT_10F_11F_11F_REV_APPLE',0x8C3B)
GL_UNSIGNED_INT_5_9_9_9_REV_APPLE=_C('GL_UNSIGNED_INT_5_9_9_9_REV_APPLE',0x8C3E)

